@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: fitcircle.c,v 1.42 2009/09/09 23:27:01 guru Exp $
+ *    $Id: fitcircle.c,v 1.50 2010/06/10 23:52:05 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
  *	Contact info: gmt.soest.hawaii.edu
  *--------------------------------------------------------------------*/
 /*
- * fitcircle <lonlatfile> [-L1] [-L2] [-S]
+ * fitcircle <lonlatfile> [-L1] [-L2] [-S[<lat>]]
  *
  * Read lon,lat pairs from GMT_stdin[file].  Find mean position and pole
  * of best-fit circle through these points.  By default, fit great
@@ -51,6 +51,7 @@
  * To find a small circle, first find the great circle pole and the mean
  * position.  Suppose the small circle pole to lie in the plane containing
  * the mean and great circle pole, and narrow down its location by bisection.
+ * Alternatively, specify the latitude of the small circle.
  *
  * Author:	W. H. F. Smith
  * Date:	16 September 1991.
@@ -63,11 +64,13 @@
 struct FITCIRCLE_CTRL {	/* All control options for this program (except common args) */
 	/* active is TRUE if the option has been activated */
 	struct L {	/* -L[<n>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG norm;	/* 1, 2, or 3 (both) */
 	} L;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
+		GMT_LONG mode;	/* 0 = find latitude, 1 = use specified latitude */
+		double lat;	/* 0 for great circle */
 	} S;
 };
 
@@ -77,17 +80,17 @@ struct	FITCIRCLE_DATA {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, greenwich = FALSE;
+	GMT_LONG	error = FALSE, greenwich = FALSE, allocate;
 
 	char	format[BUFSIZ], *not_used = NULL;
 
-	GMT_LONG	imin, imax, nrots, n_fields, n_expected_fields;
+	GMT_LONG	imin, imax, nrots, n_fields, n_expected_fields, n_read;
 	GMT_LONG	i, j, k, n_alloc, n_data, n, np;
 
 	double	lonsum, latsum, *in;
 	double	meanv[3], cross[3], cross_sum[3], gcpole[3], scpole[3];		/* Extra vectors  */
 	double	*a, *lambda, *v, *b, *z;	/* Matrix stuff */
-	double	get_small_circle (struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *center, double *gcpole, double *scpole, GMT_LONG norm, double *work);
+	double	get_small_circle (struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *center, double *gcpole, double *scpole, GMT_LONG norm, double *work, GMT_LONG mode, double slat);
 	double	rad, *work = VNULL;
 
 	FILE	*fp = NULL;
@@ -95,11 +98,11 @@ int main (int argc, char **argv)
 	struct	FITCIRCLE_DATA *data;
 	struct FITCIRCLE_CTRL *Ctrl;
 
-	void *New_Fitcircle_Ctrl (), Free_Fitcircle_Ctrl (struct FITCIRCLE_CTRL *C);
+	void *New_fitcircle_Ctrl (), Free_fitcircle_Ctrl (struct FITCIRCLE_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
- 	Ctrl = (struct FITCIRCLE_CTRL *) New_Fitcircle_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+ 	Ctrl = (struct FITCIRCLE_CTRL *) New_fitcircle_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
@@ -126,6 +129,10 @@ int main (int argc, char **argv)
 					break;
 				case 'S':
 					Ctrl->S.active = TRUE;
+					if (argv[i][2]) {
+						Ctrl->S.lat = atof (&argv[i][2]);
+						Ctrl->S.mode = 1;
+					}
                                         break;
 				default:
 					error = TRUE;
@@ -142,8 +149,8 @@ int main (int argc, char **argv)
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
-		fprintf (stderr, "fitcircle %s - find best-fitting great circle to points on sphere\n\n", GMT_VERSION);
-		fprintf(stderr,"usage:  fitcircle [<input_file>] -L[<n>] [%s] [-S] [-V] [%s]\n", GMT_H_OPT, GMT_t_OPT);
+		fprintf (stderr, "fitcircle %s - Find best-fitting great circle to points on sphere\n\n", GMT_VERSION);
+		fprintf(stderr,"usage:  fitcircle [<input_file>] -L[<n>] [%s] [-S[<lat>]] [-V] [%s]\n", GMT_H_OPT, GMT_t_OPT);
 		fprintf(stderr,"\t[%s] [%s]\n\n", GMT_bi_OPT, GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -153,6 +160,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		GMT_explain_option ('H');
 		fprintf(stderr,"\t-S will attempt to fit a small circle rather than a great circle.\n");
+		fprintf(stderr,"\t   Optionally append the latitude of the small circle you want to fit\n");
 		GMT_explain_option ('V');
 		GMT_explain_option (':');
 		GMT_explain_option ('i');
@@ -190,7 +198,7 @@ int main (int argc, char **argv)
 #endif
 	}
 	n_alloc = GMT_CHUNK;
-	n_data = 0;
+	n_data = n_read = 0;
 	lonsum = latsum = 0.0;
 
 	data = (struct FITCIRCLE_DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct FITCIRCLE_DATA), GMT_program);
@@ -202,9 +210,11 @@ int main (int argc, char **argv)
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+		n_read++;
+
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields,  n_expected_fields, n_data);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields,  n_expected_fields, n_data);
+			continue;
 		}
 
 		lonsum += in[GMT_X];
@@ -220,7 +230,8 @@ int main (int argc, char **argv)
         if (fp != GMT_stdin) GMT_fclose(fp);
         
       	data = (struct FITCIRCLE_DATA *) GMT_memory ((void *)data, (size_t)n_data, sizeof(struct FITCIRCLE_DATA), GMT_program);
-	if (Ctrl->S.active && (Ctrl->L.norm%2) ) work = (double *) GMT_memory (VNULL, (size_t)n_data, sizeof(double), GMT_program);
+	allocate = (Ctrl->S.active && (Ctrl->L.norm%2)) ;
+	if (allocate) work = (double *) GMT_memory (VNULL, (size_t)n_data, sizeof(double), GMT_program);
 
 	lonsum /= n_data;
 	latsum /= n_data;
@@ -244,8 +255,8 @@ int main (int argc, char **argv)
 	if (Ctrl->L.norm%2) {
 		GMT_cart_to_geo (&latsum, &lonsum, meanv, TRUE);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL1 Average Position (Fisher's Method)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL1 Average Position (Fisher's Method)\n");
 
 		cross_sum[0] = cross_sum[1] = cross_sum[2] = 0.0;
 		for (i = 0; i < n_data; i++) {
@@ -266,23 +277,23 @@ int main (int argc, char **argv)
 
 		GMT_cart_to_geo (&latsum, &lonsum, cross_sum, TRUE);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL1 N Hemisphere Great Circle Pole (Cross-Averaged)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL1 N Hemisphere Great Circle Pole (Cross-Averaged)\n");
 		latsum = -latsum;
 		lonsum = d_atan2d(-cross_sum[1], -cross_sum[0]);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL1 S Hemisphere Great Circle Pole (Cross-Averaged)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL1 S Hemisphere Great Circle Pole (Cross-Averaged)\n");
 		if (Ctrl->S.active) {
 			if (gmtdefs.verbose) fprintf (stderr,"Fitting small circle using L1 norm.\n");
-			rad = get_small_circle (data, n_data, meanv, gcpole, scpole, 1, work);
+			rad = get_small_circle (data, n_data, meanv, gcpole, scpole, 1, work, Ctrl->S.mode, Ctrl->S.lat);
 			if (rad >= 0.0) {
 				GMT_cart_to_geo (&latsum, &lonsum, scpole, TRUE);
 				if (greenwich && lonsum < 0.0) lonsum += 360.0;
-				fprintf (GMT_stdout, format, lonsum, latsum);
-				fprintf (GMT_stdout, "\tL1 Small Circle Pole.  ");
+				fprintf (stdout, format, lonsum, latsum);
+				fprintf (stdout, "\tL1 Small Circle Pole.  ");
 				sprintf(format, "Distance from Pole to L1 Small Circle (degrees):     %s\n", gmtdefs.d_format);
-				fprintf (GMT_stdout, format, rad);
+				fprintf (stdout, format, rad);
 			}
 		}
 	}
@@ -315,8 +326,8 @@ int main (int argc, char **argv)
 			for (i = 0; i < 3; i++) meanv[i] = v[imax*np+i];
 		GMT_cart_to_geo (&latsum, &lonsum, meanv, TRUE);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL2 Average Position (Eigenval Method)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL2 Average Position (Eigenval Method)\n");
 
 		if (v[imin*np+2] < 0.0)	/* Eigvec is in S Hemisphere  */
 			for (i = 0; i < 3; i++) gcpole[i] = -v[imin*np+i];
@@ -325,13 +336,13 @@ int main (int argc, char **argv)
 
 		GMT_cart_to_geo (&latsum, &lonsum, gcpole, TRUE);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL2 N Hemisphere Great Circle Pole (Eigenval Method)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL2 N Hemisphere Great Circle Pole (Eigenval Method)\n");
 		latsum = -latsum;
 		lonsum = d_atan2d(-gcpole[1], -gcpole[0]);
 		if (greenwich && lonsum < 0.0) lonsum += 360.0;
-		fprintf (GMT_stdout, format, lonsum, latsum);
-		fprintf (GMT_stdout, "\tL2 S Hemisphere Great Circle Pole (Eigenval Method)\n");
+		fprintf (stdout, format, lonsum, latsum);
+		fprintf (stdout, "\tL2 S Hemisphere Great Circle Pole (Eigenval Method)\n");
 
 		GMT_free ((void *)v);
 		GMT_free ((void *)z);
@@ -340,29 +351,29 @@ int main (int argc, char **argv)
 		GMT_free ((void *)a);
 		if (Ctrl->S.active) {
 			if (gmtdefs.verbose) fprintf(stderr,"%s: Fitting small circle using L2 norm.\n", GMT_program);
-			rad = get_small_circle(data, n_data, meanv, gcpole, scpole, 2, work);
+			rad = get_small_circle(data, n_data, meanv, gcpole, scpole, 2, work, Ctrl->S.mode, Ctrl->S.lat);
 			if (rad >= 0.0) {
 				/* True when small circle fits better than great circle */
 				GMT_cart_to_geo (&latsum, &lonsum, scpole, TRUE);
 				if (greenwich && lonsum < 0.0) lonsum += 360.0;
-				fprintf (GMT_stdout, format, lonsum, latsum);
-				fprintf (GMT_stdout, "\tL2 Small Circle Pole.  ");
+				fprintf (stdout, format, lonsum, latsum);
+				fprintf (stdout, "\tL2 Small Circle Pole.  ");
 				sprintf(format, "Distance from Pole to L2 Small Circle (degrees):     %s\n", gmtdefs.d_format);
-				fprintf (GMT_stdout, format, rad);
+				fprintf (stdout, format, rad);
 			}
 		}
 	}
-	if (Ctrl->S.active && (Ctrl->L.norm%2) ) GMT_free ((void *)work);
+	if (allocate) GMT_free ((void *)work);
 	GMT_free ((void *)data);
 
-	Free_Fitcircle_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_fitcircle_Ctrl (Ctrl);	/* Deallocate control structure */
 	
 	GMT_end (argc, argv);
 	
 	exit (EXIT_SUCCESS);
 }
 
-double	get_small_circle (struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *center, double *gcpole, double *scpole, GMT_LONG norm, double *work)
+double	get_small_circle (struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *center, double *gcpole, double *scpole, GMT_LONG norm, double *work, GMT_LONG mode, double slat)
 {
 
 	/* Find scpole, the pole to the best-fit small circle, 
@@ -395,8 +406,18 @@ double	get_small_circle (struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *ce
 		for (i = 0; i < 3; i++) b[i] = gcpole[i];
 	}
 
-	/* Now a is at center and b is at pole on correct side.
-		Try to bracket a minimum.  Move from b toward
+	/* Now a is at center and b is at pole on correct side. */
+	
+	if (mode) {	/* Want a specified latitude */
+		afactor = sind (slat);
+		bfactor = cosd (slat);
+		for (i = 0; i < 3; i++) scpole[i] = (afactor * a[i] + bfactor * b[i]);
+		GMT_normalize3v (scpole);
+		fit = circle_misfit (data, ndata, scpole, norm, work, &circle_distance);
+		return (90.0-slat);
+	}
+	
+	/* Try to bracket a minimum.  Move from b toward
 	a in 1 degree steps:  */
 
 	afit = circle_misfit(data, ndata, a, norm, work, &circle_distance);
@@ -514,10 +535,10 @@ double	circle_misfit(struct FITCIRCLE_DATA *data, GMT_LONG ndata, double *pole,
 	return (norm == 1) ? misfit : sqrt (misfit);
 }
 
-void *New_Fitcircle_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_fitcircle_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct FITCIRCLE_CTRL *C;
 	
-	C = (struct FITCIRCLE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct FITCIRCLE_CTRL), "New_Fitcircle_Ctrl");
+	C = (struct FITCIRCLE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct FITCIRCLE_CTRL), "New_fitcircle_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -526,6 +547,6 @@ void *New_Fitcircle_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Fitcircle_Ctrl (struct FITCIRCLE_CTRL *C) {	/* Deallocate control structure */
+void Free_fitcircle_Ctrl (struct FITCIRCLE_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
