@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_customio.c,v 1.75 2009/05/15 08:16:21 guru Exp $
+ *	$Id: gmt_customio.c,v 1.91 2010/03/23 00:13:13 jluis Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -28,9 +28,8 @@
  * To add another data format:
  *
  *	1. Write the five required routines (see below).
- *	2. increment parameter GMT_N_GRD_FORMATS in file gmt_grdio.h
- *	3. Append another entry in the gmt_customio.h file.
- *	4. Provide another entry in the $GMT_SHAREDIR/conf/gmt_formats.conf file
+ *	2. Place prototypes in the gmt_customio.h file.
+ *	3. Provide another text entry in Grdformats.txt
  *
  * Author:	Paul Wessel
  * Date:	9-SEP-1992
@@ -69,8 +68,8 @@ GMT_LONG GMT_native_write_grd_header (FILE *fp, struct GRD_HEADER *header);
 GMT_LONG GMT_native_skip_grd_header (FILE *fp, struct GRD_HEADER *header);
 GMT_LONG GMT_native_read_grd_info (struct GRD_HEADER *header);
 GMT_LONG GMT_native_write_grd_info (struct GRD_HEADER *header);
-GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex);
-GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex);
+GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex);
+GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex);
 
 void GMT_grdio_init (void) {
 	GMT_LONG id;
@@ -273,6 +272,16 @@ void GMT_grdio_init (void) {
 	GMT_io_readgrd[id]    = (PFL) GMT_agc_read_grd;
 	GMT_io_writegrd[id]   = (PFL) GMT_agc_write_grd;
 
+#ifdef USE_GDAL
+	/* FORMAT # 22: Import via the GDAL interface */
+
+	id = 22;
+	GMT_io_readinfo[id]   = (PFL) GMT_gdal_read_grd_info;
+	GMT_io_updateinfo[id] = (PFL) GMT_gdal_write_grd_info;
+	GMT_io_writeinfo[id]  = (PFL) GMT_gdal_write_grd_info;
+	GMT_io_readgrd[id]    = (PFL) GMT_gdal_read_grd;
+	GMT_io_writegrd[id]   = (PFL) GMT_gdal_write_grd;
+#endif
 	/*
 	 * ----------------------------------------------
 	 * ADD CUSTOM FORMATS BELOW AS THEY ARE NEEDED */
@@ -385,7 +394,7 @@ GMT_LONG GMT_ras_write_grd_info (struct GRD_HEADER *header)
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -398,7 +407,7 @@ GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	GMT_LONG i, j, j2, width_in, width_out, height_in, i_0_out, n2;
 	GMT_LONG kk, ij;
 	FILE *fp;
-	BOOLEAN piping = FALSE, check;
+	GMT_LONG piping = FALSE, check;
 	unsigned char *tmp;
 	struct rasterfile h;
 	GMT_LONG *k;
@@ -460,8 +469,8 @@ GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	if (piping) {	/* Skip data by reading it */
 		for (j = last_row + 1; j < header->ny; j++) if (GMT_fread ((void *) tmp, sizeof (unsigned char), (size_t)n2, fp) < (size_t)n2) return (GMT_GRDIO_READ_FAILED);
 	}
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -474,7 +483,7 @@ GMT_LONG GMT_ras_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_ras_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_ras_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to write  [Use entire file if 0,0,0,0] */
@@ -487,7 +496,7 @@ GMT_LONG GMT_ras_write_grd (struct GRD_HEADER *header, float *grid, double w, do
 	GMT_LONG *k;
 	GMT_LONG kk, ij;
 
-	BOOLEAN check, do_header = TRUE;
+	GMT_LONG check, do_header = TRUE;
 
 	unsigned char *tmp;
 
@@ -582,28 +591,28 @@ GMT_LONG GMT_read_rasheader (FILE *fp, struct rasterfile *h)
 
 		switch (i) {
 			case 0:
-				h->magic = value;
+				h->magic = (int)value;
 				break;
 			case 1:
-				h->width = value;
+				h->width = (int)value;
 				break;
 			case 2:
-				h->height = value;
+				h->height = (int)value;
 				break;
 			case 3:
-				h->depth = value;
+				h->depth = (int)value;
 				break;
 			case 4:
-				h->length = value;
+				h->length = (int)value;
 				break;
 			case 5:
-				h->type = value;
+				h->type = (int)value;
 				break;
 			case 6:
-				h->maptype = value;
+				h->maptype = (int)value;
 				break;
 			case 7:
-				h->maplength = value;
+				h->maplength = (int)value;
 				break;
 		}
 	}
@@ -699,7 +708,7 @@ GMT_LONG GMT_is_native_grid (struct GRD_HEADER *header)
 	if (t_head.nx <= 0 || t_head.ny <= 0) return (GMT_GRDIO_BAD_VAL);		/* Garbage for nx or ny */
 	nm = ((GMT_LONG)t_head.nx) * ((GMT_LONG)t_head.ny);
 	if (nm <= 0) return (GMT_GRDIO_BAD_VAL);		/* Overflow for nx * ny? */
-	item_size = (buf.st_size - GRD_HEADER_SIZE) / nm;	/* Estimate size of elements */
+	item_size = (double)((buf.st_size - GRD_HEADER_SIZE) / nm);	/* Estimate size of elements */
 	size = irint (item_size);
 	if (!GMT_IS_ZERO(item_size - (double)size)) return (GMT_GRDIO_BAD_VAL);	/* Size not an integer */
 	
@@ -735,7 +744,7 @@ GMT_LONG GMT_is_native_grid (struct GRD_HEADER *header)
 	return (header->type);
 }
 
-GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -749,7 +758,7 @@ GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	GMT_LONG *k;
 	GMT_LONG kk, ij;
 	FILE *fp;
-	BOOLEAN piping = FALSE, check = FALSE;
+	GMT_LONG piping = FALSE, check = FALSE;
 	unsigned int *tmp, ival;
 
 	if (!strcmp (header->name, "=")) {
@@ -804,8 +813,8 @@ GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 		for (j = last_row + 1; j < header->ny; j++) if (GMT_fread ((void *) tmp, sizeof (unsigned int), (size_t)mx, fp) < (size_t)mx) return (GMT_GRDIO_READ_FAILED);
 	}
 
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -827,7 +836,7 @@ GMT_LONG GMT_bit_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_bit_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_bit_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -841,7 +850,7 @@ GMT_LONG GMT_bit_write_grd (struct GRD_HEADER *header, float *grid, double w, do
 	GMT_LONG j, j2, width_in, width_out, height_out, mx, word, bit, err, inc = 1;
 	GMT_LONG first_col, last_col, first_row, last_row;
 	GMT_LONG kk, ij;
-	BOOLEAN check = FALSE, do_header = TRUE;
+	GMT_LONG check = FALSE, do_header = TRUE;
 	unsigned int *tmp, ival;
 
 	FILE *fp;
@@ -1034,7 +1043,7 @@ GMT_LONG GMT_native_write_grd_info (struct GRD_HEADER *header)
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -1055,8 +1064,8 @@ GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w,
 	GMT_LONG kk, ij;
 	GMT_LONG width_out;		/* Width of row as return (may include padding) */
 	FILE *fp;			/* File pointer to data or pipe */
-	BOOLEAN piping = FALSE;		/* TRUE if we read input pipe instead of from file */
-	BOOLEAN check = FALSE;		/* TRUE if nan-proxies are used to signify NaN (for non-floating point types) */
+	GMT_LONG piping = FALSE;		/* TRUE if we read input pipe instead of from file */
+	GMT_LONG check = FALSE;		/* TRUE if nan-proxies are used to signify NaN (for non-floating point types) */
 	void *tmp;			/* Array pointer for reading in rows of data */
 
 	if (!strcmp (header->name, "=")) {
@@ -1116,8 +1125,8 @@ GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w,
 		for (j = last_row + 1; j < header->ny; j++) if (GMT_fread (tmp, (size_t)size, (size_t)header->nx, fp) < (size_t)header->nx) return (GMT_GRDIO_READ_FAILED);
 	}
 
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -1142,7 +1151,7 @@ GMT_LONG GMT_native_read_grd (struct GRD_HEADER *header, float *grid, double w,
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to write out  [Use entire file if 0,0,0,0] */
@@ -1163,8 +1172,8 @@ GMT_LONG GMT_native_write_grd (struct GRD_HEADER *header, float *grid, double w,
 	GMT_LONG width_in;		/* Number of items in one row of the subregion */
 	GMT_LONG ij;
 	FILE *fp;			/* File pointer to data or pipe */
-	BOOLEAN check = FALSE;		/* TRUE if nan-proxies are used to signify NaN (for non-floating point types) */
-	BOOLEAN do_header = TRUE;	/* TRUE if we should write the header first */
+	GMT_LONG check = FALSE;		/* TRUE if nan-proxies are used to signify NaN (for non-floating point types) */
+	GMT_LONG do_header = TRUE;	/* TRUE if we should write the header first */
 	void *tmp;			/* Array pointer for writing in rows of data */
 
 	if (!strcmp (header->name, "=")) {
@@ -1461,7 +1470,7 @@ GMT_LONG GMT_srf_write_grd_info (struct GRD_HEADER *header)
 	else if ((fp = GMT_fopen (header->name, "rb+")) == NULL && (fp = GMT_fopen (header->name, "wb")) == NULL)
 		return (GMT_GRDIO_CREATE_FAILED);
 
-	strcpy (h.id,"DSBB");
+	strncpy (h.id, "DSBB", (size_t)4);
 	h.nx = (short int)header->nx;	 h.ny = (short int)header->ny;
 	if (header->node_offset) {
 		h.x_min = header->x_min + header->x_inc/2;	 h.x_max = header->x_max - header->x_inc/2;
@@ -1483,8 +1492,13 @@ GMT_LONG GMT_srf_write_grd_info (struct GRD_HEADER *header)
 GMT_LONG GMT_read_srfheader6 (FILE *fp, struct srf_header6 *h)
 {
 	/* Reads the header of a Surfer 6 gridfile */
+	/* if (GMT_fread ((void *)h, sizeof (struct srf_header6), (size_t)1, fp) < (size_t)1) return (GMT_GRDIO_READ_FAILED); */
+
+	/* UPDATE: Because srf_header6 is not 64-bit aligned we must read it in parts */
+	if (GMT_fread ((void *)h->id, 4*sizeof (char), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED); 
+	if (GMT_fread ((void *)&h->nx, 2*sizeof (short int), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED);
+	if (GMT_fread ((void *)&h->x_min, sizeof (struct srf_header6) - ((long)&h->x_min - (long)h->id), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED);
 
-	if (GMT_fread ((void *)h, sizeof (struct srf_header6), (size_t)1, fp) < (size_t)1) return (GMT_GRDIO_READ_FAILED); 
 	return (GMT_NOERROR);
 }
 
@@ -1493,17 +1507,29 @@ GMT_LONG GMT_read_srfheader7 (FILE *fp, struct srf_header7 *h)
 	/* Reads the header of a Surfer 7 gridfile */
 
 	if (GMT_fseek (fp, 3*sizeof(int), SEEK_SET)) return (GMT_GRDIO_SEEK_FAILED);	/* skip the first 12 bytes */
-	if (GMT_fread ((void *)h, sizeof (struct srf_header7), (size_t)1, fp) < (size_t)1) return (GMT_GRDIO_READ_FAILED);
+	/* if (GMT_fread ((void *)h, sizeof (struct srf_header7), (size_t)1, fp) < (size_t)1) return (GMT_GRDIO_READ_FAILED); */
+
+	/* UPDATE: Because srf_header6 is not 64-bit aligned we must read it in parts */
+	if (GMT_fread ((void *)h->id2, 4*sizeof (char), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED); 
+	if (GMT_fread ((void *)&h->len_g, 3*sizeof (int), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED);
+	if (GMT_fread ((void *)&h->x_min, 8*sizeof (double), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED);
+	if (GMT_fread ((void *)h->id3, 4*sizeof (char), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED); 
+	if (GMT_fread ((void *)&h->len_d, sizeof (int), (size_t)1, fp) != 1) return (GMT_GRDIO_READ_FAILED);
+
 	return (GMT_NOERROR);
 }
 
 GMT_LONG GMT_write_srfheader (FILE *fp, struct srf_header6 *h)
 {
-	if (GMT_fwrite ((void *)h, sizeof (struct srf_header6), (size_t)1, fp) < (size_t)1) return (GMT_GRDIO_WRITE_FAILED); 
+	/* if (GMT_fwrite ((void *)h, sizeof (struct srf_header6), (size_t)1, fp) < (size_t)1) return (GMT_GRDIO_WRITE_FAILED); */
+	/* UPDATE: Because srf_header6 is not 64-bit aligned we must write it in parts */
+	if (GMT_fwrite ((void *)h->id, 4*sizeof (char), (size_t)1, fp) != 1) return (GMT_GRDIO_WRITE_FAILED); 
+	if (GMT_fwrite ((void *)&h->nx, 2*sizeof (short int), (size_t)1, fp) != 1) return (GMT_GRDIO_WRITE_FAILED);
+	if (GMT_fwrite ((void *)&h->x_min, sizeof (struct srf_header6) - ((long)&h->x_min - (long)h->id), (size_t)1, fp) != 1) return (GMT_GRDIO_WRITE_FAILED);
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:     	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
@@ -1524,7 +1550,7 @@ GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	GMT_LONG kk, ij;
 	GMT_LONG width_out;		/* Width of row as return (may include padding) */
 	FILE *fp;			/* File pointer to data or pipe */
-	BOOLEAN piping = FALSE;		/* TRUE if we read input pipe instead of from file */
+	GMT_LONG piping = FALSE;		/* TRUE if we read input pipe instead of from file */
 	void *tmp;			/* Array pointer for reading in rows of data */
 	header->nan_value = 0.1701410e39;	/* Test value in Surfer grids */
 
@@ -1549,7 +1575,7 @@ GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	type = GMT_grdformats[header->type][1];
 	size = GMT_grd_data_size (header->type, &header->nan_value);
 
-	GMT_err_pass (GMT_grd_prep_io (header, &w, &e, &s, &n, &width_in, &height_in, &first_col, &last_col, &first_row, &last_row, &k), header->name);;
+	GMT_err_pass (GMT_grd_prep_io (header, &w, &e, &s, &n, &width_in, &height_in, &first_col, &last_col, &first_row, &last_row, &k), header->name);
 
 	width_out = width_in;		/* Width of output array */
 	if (pad[0] > 0) width_out += pad[0];
@@ -1564,7 +1590,7 @@ GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	}
 	if ( (last_row - first_row + 1) != header->ny) {    /* We have a sub-region */
 		/* Surfer grids are stored starting from Lower Left, which is contrary to
-		   the rest of GMT grids that start at Top Left. So we must do a shift here */
+		   the rest of GMT grids that start at Top Left. So we must do a flip here */
 		first_row = header->ny - height_in - first_row;
 		last_row = first_row + height_in - 1;
 	}
@@ -1595,8 +1621,8 @@ GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 		for (j = last_row + 1; j < header->ny; j++) if (GMT_fread (tmp, size, (size_t)header->nx, fp) < (size_t)header->nx) return (GMT_GRDIO_READ_FAILED);
 	}
 
-	header->nx = width_in;
-	header->ny = height_in;
+	header->nx = (int)width_in;
+	header->ny = (int)height_in;
 	header->x_min = w;
 	header->x_max = e;
 	header->y_min = s;
@@ -1622,7 +1648,7 @@ GMT_LONG GMT_srf_read_grd (struct GRD_HEADER *header, float *grid, double w, dou
 	return (GMT_NOERROR);
 }
 
-GMT_LONG GMT_srf_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, BOOLEAN complex)
+GMT_LONG GMT_srf_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex)
 {	/* header:	grid structure header */
 	/* grid:	array with final grid */
 	/* w,e,s,n:	Sub-region to write out  [Use entire file if 0,0,0,0] */
@@ -1690,7 +1716,7 @@ GMT_LONG GMT_srf_write_grd (struct GRD_HEADER *header, float *grid, double w, do
 
 	/* store header information and array */
 
-	strcpy (h.id,"DSBB");
+	strncpy (h.id, "DSBB", (size_t)4);
 	h.nx = (short int)header->nx;	 h.ny = (short int)header->ny;
 	if (header->node_offset) {
 		h.x_min = header->x_min + header->x_inc/2;	 h.x_max = header->x_max - header->x_inc/2;
@@ -1723,6 +1749,168 @@ GMT_LONG GMT_srf_write_grd (struct GRD_HEADER *header, float *grid, double w, do
 	return (GMT_NOERROR);
 }
 
+#ifdef USE_GDAL
+#include "gmt_gdalread.c"
+/* Experimental GDAL support */
+/*-----------------------------------------------------------
+ * Format # :	22
+ * Type :	Native binary (float) C file
+ * Prefix :	GMT_gdal_
+ * Author :	Joaquim Luis
+ * Date :	06-SEP-2009
+ * 
+ * Purpose:	to access data read trough the GDAL interface
+ * Functions :	GMT_gdal_read_grd_info, GMT_gdal_write_grd_info,
+ *		GMT_gdal_write_grd_info, GMT_gdal_read_grd, GMT_gdal_write_grd
+ *-----------------------------------------------------------*/
+
+GMT_LONG GMT_gdal_read_grd_info (struct GRD_HEADER *header) {
+	struct GDALREAD_CTRL *to_gdalread;
+	struct GD_CTRL *from_gdalread;
+
+	if (!strcmp (header->name, "=")) {
+		fprintf (stderr, "Pipes cannot be used within the GDAL interface.\n");
+		return (GMT_GRDIO_OPEN_FAILED);
+	}
+
+	/* Allocate new control structures */
+	to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_gdalread_Ctrl");
+	from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_gd_Ctrl");
+
+	to_gdalread->M.active = 1;		/* Metadata only */
+	to_gdalread->C.active = 1;		/* Force info in grid registration */
+	if (GMT_gdalread ( header->name, to_gdalread, from_gdalread)) {
+		fprintf (stderr, "ERROR reading file with gdalread.\n");
+		return (GMT_GRDIO_OPEN_FAILED);
+	}
+
+	header->type = 22;
+
+	header->node_offset = 0;	/* Grid node registration */
+	strcpy (header->title, "Grid imported trhough GDAL");
+	header->nx = from_gdalread->RasterXsize;	header->ny = from_gdalread->RasterYsize;
+	header->x_min = from_gdalread->hdr[0];
+	header->x_max = from_gdalread->hdr[1];
+	header->y_min = from_gdalread->hdr[2];
+	header->y_max = from_gdalread->hdr[3];
+	header->z_min = from_gdalread->hdr[4];
+	header->z_max = from_gdalread->hdr[5];
+	header->x_inc = from_gdalread->hdr[7];
+	header->y_inc = from_gdalread->hdr[8];
+	header->z_scale_factor = 1;	header->z_add_offset = 0;
+
+	GMT_free((void *) to_gdalread);
+	GMT_free((void *) from_gdalread);
+
+	return (GMT_NOERROR);
+}
+
+GMT_LONG GMT_gdal_write_grd_info (struct GRD_HEADER *header) {
+	return (GMT_NOERROR);
+}
+
+GMT_LONG GMT_gdal_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex) {
+	/* header:     	grid structure header */
+	/* grid:	array with final grid */
+	/* w,e,s,n:	Sub-region to extract  [Use entire file if 0,0,0,0] */
+	/* padding:	# of empty rows/columns to add on w, e, s, n of grid, respectively */
+	/* complex:	TRUE if array is to hold real and imaginary parts (read in real only) */
+	/*		Note: The file has only real values, we simply allow space in the array */
+	/*		for imaginary parts when processed by grdfft etc. */
+
+	struct GDALREAD_CTRL *to_gdalread;
+	struct GD_CTRL *from_gdalread;
+	GMT_LONG i, j, nm, nBand;
+	char	strR [128]; 
+
+	/* Allocate new control structures */
+	to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_gdalread_Ctrl");
+	from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_gd_Ctrl");
+
+	to_gdalread->C.active = 1;		/* Force info in grid node registration */
+	if (w != 0 || e != 0 || s != 0 || n != 0) {	/* We have a Sub-region demand */
+		to_gdalread->R.active = 1;
+		sprintf(strR, "-R%.10f/%.10f/%.10f/%.10f", w, e, s, n);
+		to_gdalread->R.region = strR;
+	}
+	if (pad[0] > 0) {	/* Here we assume that all pad[0] ... pad[3] are equal. Otherwise ... */
+		to_gdalread->p.active = 1;
+		to_gdalread->p.pad = (int)pad[0];
+	}
+
+	if (GMT_gdalread ( header->name, to_gdalread, from_gdalread)) {
+		fprintf (stderr, "ERROR reading file with gdalread.\n");
+		return (GMT_GRDIO_OPEN_FAILED);
+	}
+	if (w != 0 || e != 0 || s != 0 || n != 0) {	/* We had a Sub-region demand */
+		header->nx = from_gdalread->RasterXsize;
+		header->ny = from_gdalread->RasterYsize;
+		header->x_min = from_gdalread->hdr[0];
+		header->x_max = from_gdalread->hdr[1];
+		header->y_min = from_gdalread->hdr[2];
+		header->y_max = from_gdalread->hdr[3];
+		header->z_min = from_gdalread->hdr[4];
+		header->z_max = from_gdalread->hdr[5];
+	}
+
+	nm = header->nx * header->ny;
+
+	if (from_gdalread->Float.active)
+		grid = memcpy((void *)grid, (void *)from_gdalread->Float.data, header->nx*header->ny * sizeof(float));
+	else {
+		/* Convert everything else do float */
+		nBand = 0;		/* Need a solution to RGB or multiband files */
+		i = nBand * nm;
+		if (from_gdalread->UInt8.active)
+			for (j = 0; j < nm; j++)
+				grid[j] = (float)from_gdalread->UInt8.data[j+i];
+		else if (from_gdalread->UInt16.active)
+			for (j = 0; j < nm; j++)
+				grid[j] = (float)from_gdalread->UInt16.data[j+i];
+		else if (from_gdalread->Int16.active)
+			for (j = 0; j < nm; j++)
+				grid[j] = (float)from_gdalread->Int16.data[j+i];
+		else if (from_gdalread->Int32.active)
+			for (j = 0; j < nm; j++)
+				grid[j] = (float)from_gdalread->Int32.data[j+i];
+		else {
+			fprintf (stderr, "ERROR data type not suported with gdalread in gmt_customio.\n");
+			return (GMT_GRDIO_OPEN_FAILED);
+		}
+	}
+
+	if (from_gdalread->nodata != 0) {	/* Data has a nodata value */
+		if (!GMT_is_dnan (from_gdalread->nodata)) {
+			for (j = 0; j < nm; j++)
+				if (grid[j] == header->nan_value) grid[j] = GMT_f_NaN;
+		}
+	}
+	header->nan_value = GMT_f_NaN;
+
+	GMT_free((void *) to_gdalread);
+	if (from_gdalread->ColorMap == NULL) GMT_free((void *) from_gdalread->ColorMap);
+
+	if (from_gdalread->UInt8.active)
+		GMT_free ((void *)from_gdalread->UInt8.data);
+	else if (from_gdalread->Float.active)
+		GMT_free ((void *)from_gdalread->Float.data);
+	else if (from_gdalread->UInt16.active)
+		GMT_free ((void *)from_gdalread->UInt16.data);
+	else if (from_gdalread->Int16.active)
+		GMT_free ((void *)from_gdalread->Int16.data);
+	else if (from_gdalread->Int32.active)
+		GMT_free ((void *)from_gdalread->Int32.data);
+
+	GMT_free((void *) from_gdalread);
+
+	return (GMT_NOERROR);
+}
+
+GMT_LONG GMT_gdal_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, GMT_LONG *pad, GMT_LONG complex) {
+	return (GMT_NOERROR);
+}
+#endif
+
 /* Add custom code here */
 
 /* 12: NOAA NGDC MGG Format */
