@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_globals.h,v 1.44 2009/06/19 22:14:16 guru Exp $
+ *	$Id: gmt_globals.h,v 1.52 2010/06/25 20:33:48 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -135,6 +135,7 @@ struct GMT_DEFAULTS gmtdefs = {		/* Initial default values */
 	{"Standard", 		/* CHAR_ENCODING */
 	 {32, 32, 32, 32, 32}}, /* PostScript codes for degree, ring, colon, singlequote, and doublequote [Initialized to space] */
 	TRUE,			/* HISTORY */
+	{0, 0},			/* TRANSPARENCY */
 };
 
 struct GMT_FONT *GMT_font;		/* Name and height of fonts recognized by GMT */
@@ -162,9 +163,10 @@ GMT_LONG GMT_y_status_new;
 GMT_LONG GMT_x_status_old;
 GMT_LONG GMT_y_status_old;
 GMT_LONG GMT_corner = 0;
-BOOLEAN GMT_on_border_is_outside = FALSE;	/* TRUE if a point exactly on the map border shoud be considered outside the map */
-BOOLEAN GMT_world_map = FALSE;			/* TRUE if map has 360 degrees of longitude range */
-BOOLEAN GMT_world_map_tm = FALSE;		/* TRUE if GMT_TM map is global? */
+GMT_LONG GMT_on_border_is_outside = FALSE;	/* TRUE if a point exactly on the map border shoud be considered outside the map */
+GMT_LONG GMT_world_map = FALSE;			/* TRUE if map has 360 degrees of longitude range */
+GMT_LONG GMT_world_map_tm = FALSE;		/* TRUE if GMT_TM map is global? */
+GMT_LONG GMT_lon_wrap = FALSE;			/* TRUE if wrapping of longitude over 360 degrees is allowed */
 double GMT_map_width;				/* Full width in inches of this world map */
 double GMT_map_height;				/* Full height in inches of this world map */
 double GMT_half_map_size;			/* Half width in inches of this world map */
@@ -175,15 +177,14 @@ PFL GMT_overlap;				/* pointer to function checking for overlap between 2 region
 PFL GMT_map_clip;				/* pointer to functions that clip a polygon to fit inside map */
 PFD GMT_left_edge, GMT_right_edge;		/* pointers to functions that return left/right edge of map */
 PFD GMT_distance_func;				/* pointer to function returning distance between two points points */
-BOOLEAN GMT_z_periodic = FALSE;			/* TRUE if grid values are 0-360 degrees (phases etc) */
+GMT_LONG GMT_z_periodic = FALSE;			/* TRUE if grid values are 0-360 degrees (phases etc) */
 PFL GMT_wrap_around_check;			/* Does x or y wrap checks */
 PFL GMT_map_jump;				/* TRUE if we jump in x or y */
 PFB GMT_will_it_wrap;				/* TRUE if consecutive points indicate wrap */
 PFB GMT_this_point_wraps;			/* Used in above */
 PFV GMT_get_crossings;				/* Returns map crossings in x or y */
-PFL GMT_truncate;				/* Truncate polygons agains boundaries */
-BOOLEAN GMT_meridian_straight = FALSE;		/* TRUE if meridians plot as straight lines */
-BOOLEAN GMT_parallel_straight = FALSE;		/* TRUE if parallels plot as straight lines */
+GMT_LONG GMT_meridian_straight = FALSE;		/* TRUE if meridians plot as straight lines */
+GMT_LONG GMT_parallel_straight = FALSE;		/* TRUE if parallels plot as straight lines */
 GMT_LONG GMT_3D_mode = 3;				/* Determines if we draw fore and/or back 3-D box lines [Default is both] */
 char *GMT_plot_format[3][2];			/* Keeps the 6 formats for dd:mm:ss plot output */
 GMT_LONG GMT_n_lon_nodes = 360;			/* Somewhat arbitrary # of nodes for lines in longitude (may be reset in gmt_map.c) */
@@ -198,13 +199,13 @@ struct GMT_LUT *GMT_lut;		/* CPT lookup table read by GMT_read_cpt */
 struct GMT_BFN_COLOR GMT_bfn[3];	/* Structures with back/fore/nan colors */
 GMT_LONG GMT_n_colors = 0;			/* Number of colors in CPT lookup table */
 GMT_LONG GMT_cpt_flags = 0;			/* Flags controling use of BFN colors */
-BOOLEAN GMT_gray;			/* TRUE if only grayshades are needed */
-BOOLEAN GMT_b_and_w;			/* TRUE if only black and white are needed */
-BOOLEAN GMT_continuous;			/* TRUE if continuous color tables have been given */
-BOOLEAN GMT_cpt_pattern = FALSE;	/* TRUE if cpt file contains any patterns */
-BOOLEAN GMT_cpt_skip = FALSE;		/* TRUE if current z-slice is to be skipped */
+GMT_LONG GMT_gray;			/* TRUE if only grayshades are needed */
+GMT_LONG GMT_b_and_w;			/* TRUE if only black and white are needed */
+GMT_LONG GMT_continuous;			/* TRUE if continuous color tables have been given */
+GMT_LONG GMT_cpt_pattern = FALSE;	/* TRUE if cpt file contains any patterns */
+GMT_LONG GMT_cpt_skip = FALSE;		/* TRUE if current z-slice is to be skipped */
 #ifdef GMT_CPT2	
-BOOLEAN GMT_categorical = FALSE;	/* TRUE if CPT applies to categorical data */
+GMT_LONG GMT_categorical = FALSE;	/* TRUE if CPT applies to categorical data */
 #endif
 /*--------------------------------------------------------------------*/
 /*	For projection purposes */
@@ -237,6 +238,7 @@ struct GMT_IO GMT_io = {
 	{ FALSE, FALSE },
 	FALSE,
 	FALSE,
+	FALSE,
 	0,
 	{ 0, 0 },
 	-1,
@@ -253,7 +255,7 @@ struct GMT_IO GMT_io = {
 	"r",
 	"w",
 	"a+",
-	(BOOLEAN *)NULL,
+	(GMT_LONG *)NULL,
 	(GMT_LONG *)NULL,
 	(GMT_LONG *)NULL,
 	0,
@@ -280,7 +282,7 @@ PFL GMT_io_writegrd[GMT_N_GRD_FORMATS];
 double *GMT_file_scale, *GMT_file_offset, *GMT_file_nan;
 GMT_LONG *GMT_file_id;
 char **GMT_file_suffix;
-double GMT_curr_rec[BUFSIZ], GMT_prev_rec[BUFSIZ];
+double GMT_curr_rec[GMT_MAX_COLUMNS], GMT_prev_rec[GMT_MAX_COLUMNS];
 GMT_LONG GMT_pad[4] = {0, 0, 0, 0};
 GMT_LONG GMT_inc_code[2] = {0, 0};
 struct GMT_GRD_INFO GMT_grd_info;
@@ -315,7 +317,7 @@ int GMT_no_rgb[3] = {-1, -1, -1};
 int GMT_oldargc;
 char *GMT_oldargv[GMT_N_UNIQUE];	/* Pointers to old common arguments */
 
-BOOLEAN GMT_give_synopsis_and_exit = FALSE;
+GMT_LONG GMT_give_synopsis_and_exit = FALSE;
 
 struct GMT_TIME_LANGUAGE GMT_time_language;	/* For time axis */
 
