@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: pscoast.c,v 1.96 2009/06/05 00:25:11 guru Exp $
+ *	$Id: pscoast.c,v 1.105 2010/03/24 14:36:59 jluis Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -59,65 +59,65 @@
 
 struct PSCOAST_CTRL {
 	struct A {	/* -A<min_area>[/<min_level>/<max_level>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_SHORE_SELECT info;
 	} A;
 	struct C {	/* -C<fill> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_FILL fill[2];	/* lake and riverlake fill */
 	} C;
 	struct D {	/* -D<resolution> */
-		BOOLEAN active;
-		BOOLEAN force;	/* if TRUE, select next highest level if current set is not avaialble */
+		GMT_LONG active;
+		GMT_LONG force;	/* if TRUE, select next highest level if current set is not avaialble */
 		char set;	/* One of f, h, i, l, c */
 	} D;
 	struct E {	/* -Eazim/elev */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct G {	/* -G<fill> */
-		BOOLEAN active;
-		BOOLEAN clip;
+		GMT_LONG active;
+		GMT_LONG clip;
 		struct GMT_FILL fill;
 	} G;
 	struct I {	/* -I<feature>[/<pen>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG use[GMT_N_RLEVELS];
 		struct GMT_PEN pen[GMT_N_RLEVELS];
 	} I;
 	struct L {	/* -L */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_MAP_SCALE item;
 	} L;
 	struct N {	/* -N<feature>[/<pen>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG use[GMT_N_BLEVELS];
 		struct GMT_PEN pen[GMT_N_BLEVELS];
 	} N;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 	struct S {	/* -S<fill> */
-		BOOLEAN active;
-		BOOLEAN clip;
+		GMT_LONG active;
+		GMT_LONG clip;
 		struct GMT_FILL fill;
 	} S;
 	struct T {	/* -L */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_MAP_ROSE item;
 	} T;
 	struct W {	/* -W[<feature>/]<pen> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG use[GMT_MAX_GSHHS_LEVEL];
 		struct GMT_PEN pen[GMT_MAX_GSHHS_LEVEL];
 	} W;
 	struct Z {	/* -Z<z_level> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double level;
 	} Z;
 #ifdef DEBUG
 	struct DBG {	/* -+<bin> */
-		BOOLEAN active;
+		GMT_LONG active;
 		int bin;
 	} debug;
 #endif
@@ -131,10 +131,10 @@ int main (int argc, char **argv)
 
 	GMT_LONG n;
 	
-	BOOLEAN	error = FALSE, shift = FALSE, need_coast_base, recursive, fill_ocean, fill_land;
-	BOOLEAN	greenwich = FALSE, possibly_donut_hell = FALSE, fill_in_use = FALSE;
-	BOOLEAN clobber_background, paint_polygons = FALSE, donut, dumping = FALSE;
-	BOOLEAN donut_hell = FALSE, world_map_save, clipping = FALSE;
+	GMT_LONG	error = FALSE, shift = FALSE, need_coast_base, recursive, fill_ocean, fill_land;
+	GMT_LONG	greenwich = FALSE, possibly_donut_hell = FALSE, fill_in_use = FALSE;
+	GMT_LONG clobber_background, paint_polygons = FALSE, donut, dumping = FALSE;
+	GMT_LONG donut_hell = FALSE, world_map_save, clipping = FALSE;
 
 	double	west = 0.0, east = 0.0, south = 0.0, north = 0.0, bin_x[5], bin_y[5], out[2];
 	double west_border, east_border, anti_lon = 0.0, anti_lat = -90.0, edge = 720.0;
@@ -152,11 +152,11 @@ int main (int argc, char **argv)
 
 	void recursive_painting (int k0, int np, struct GMT_GSHHS_POL *p, int level, int start_level, struct GMT_FILL fill[]);
 	void recursive_clipping (int k0, int np, struct GMT_GSHHS_POL *p, int level, int start_level, int *n_pieces);
-	void *New_Pscoast_Ctrl (), Free_Pscoast_Ctrl (struct PSCOAST_CTRL *C);
+	void *New_pscoast_Ctrl (), Free_pscoast_Ctrl (struct PSCOAST_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct PSCOAST_CTRL *) New_Pscoast_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
+	Ctrl = (struct PSCOAST_CTRL *) New_pscoast_Ctrl ();		/* Allocate and initialize defaults in a new control structure */
 
 	/* Check and interpret the command line arguments */
 
@@ -388,7 +388,11 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t[%s] [-K] [%s]\n", GMT_Jz_OPT, GMT_SCALE);
 		fprintf (stderr, "\t[-N<feature>[/<pen>]] [-O] [-P] [-Q] [-S<fill>]\n");
 		fprintf (stderr, "\t[%s] [%s]\n", GMT_TROSE, GMT_U_OPT);
-		fprintf (stderr, "\t[-V] [-W[<feature>/][<pen>]] [%s] [%s] [-Z<zlevel>] [%s] [%s] [%s]\n", GMT_X_OPT, GMT_Y_OPT, GMT_bo_OPT, GMT_c_OPT, GMT_mo_OPT);
+		fprintf (stderr, "\t[-V] [-W[<feature>/][<pen>]] [%s] [%s] [-Z<zlevel>]\n", GMT_X_OPT, GMT_Y_OPT);
+		fprintf (stderr, "\t[%s] [%s] [%s]\n", GMT_bo_OPT, GMT_c_OPT, GMT_mo_OPT);
+#ifdef DEBUG
+		fprintf (stderr, "\t[-+<bin>]\n");
+#endif
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -460,6 +464,9 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-m Dump a multisegment ascii (or binary, see -bo) file to standard output.  No plotting occurs\n");
 		fprintf (stderr, "\t   Specify any combination of -W, -I, -N.  Optionally, append 1-char\n");
 		fprintf (stderr, "\t   segment header <flag> [%c]\n", GMT_io.EOF_flag[GMT_OUT]);
+#ifdef DEBUG
+		fprintf (stderr, "\t-+ Print only a single bin (debug option)\n");
+#endif
 		GMT_explain_option ('.');
 		exit (EXIT_FAILURE);
 	}
@@ -552,7 +559,7 @@ int main (int argc, char **argv)
 	if (error) exit (EXIT_FAILURE);
 
 	if (Ctrl->D.force) Ctrl->D.set = GMT_shore_adjust_res (Ctrl->D.set);
-	base = GMT_set_resolution (&Ctrl->D.set, 'D');
+	base = (int)GMT_set_resolution (&Ctrl->D.set, 'D');
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
 	fill[0] = Ctrl->S.fill;
@@ -607,13 +614,16 @@ int main (int argc, char **argv)
 #ifdef SET_IO_MODE
 		GMT_setmode (GMT_OUT);
 #endif
-		if (!GMT_io.binary[1]) fprintf (GMT_stdout, "# Data from the %s resolution GMT shoreline, borders, and rivers database\n", shore_resolution[base]);
+		if (!GMT_io.binary[1]) {
+			sprintf (comment, "# Data from the %s resolution GMT shoreline, borders, and rivers database\n", shore_resolution[base]);
+			GMT_fputs (comment, GMT_stdout);
+		}
 	}
 	else {
 		if (Ctrl->Q.active)
-			GMT_ps.clip_off = TRUE;	/* Signal that this program terminates clipping that initiated prior to this process */
+			GMT_ps.clip = -1;	/* Signal that this program terminates clipping that initiated prior to this process */
 		else if (clipping)
-			GMT_ps.clip_on = TRUE;	/* Signal that this program initiates clipping that wil outlive this process */
+			GMT_ps.clip = +1;	/* Signal that this program initiates clipping that wil outlive this process */
 
 		GMT_plotinit (argc, argv);
 
@@ -626,7 +636,7 @@ int main (int argc, char **argv)
 
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 			
-			Free_Pscoast_Ctrl (Ctrl);	/* Deallocate control structure */
+			Free_pscoast_Ctrl (Ctrl);	/* Deallocate control structure */
 
 			GMT_end (argc, argv);
 			exit (EXIT_SUCCESS);
@@ -733,11 +743,11 @@ int main (int argc, char **argv)
 
 	for (ind = 0; need_coast_base && ind < c.nb; ind++) {	/* Loop over necessary bins only */
 
-		bin = c.bins[ind];
+		bin = (int)c.bins[ind];
 #ifdef DEBUG
-		if (Ctrl->debug.bin >= 0 && bin != Ctrl->debug.bin) continue;
+		if (Ctrl->debug.active && bin != Ctrl->debug.bin) continue;
 #endif
-		if ((err = GMT_get_shore_bin (ind, &c))) {
+		if ((err = (int)GMT_get_shore_bin (ind, &c))) {
 			fprintf (stderr, "%s: %s [%s resolution shoreline]\n", GMT_program, GMT_strerror(err), shore_resolution[base]);
 			exit (EXIT_FAILURE);
 		}
@@ -770,11 +780,11 @@ int main (int argc, char **argv)
 
 			/* Assemble one or more segments into polygons */
 
-			if ((np = GMT_assemble_shore (&c, direction, TRUE, shift, west_border, east_border, &p)) == 0) continue;
+			if ((np = (int)GMT_assemble_shore (&c, direction, TRUE, shift, west_border, east_border, &p)) == 0) continue;
 
 			/* Get clipped polygons in x,y inches that can be plotted */
 
-			np_new = GMT_prep_polygons (&p, np, donut_hell, step, bin_trouble);
+			np_new = (int)GMT_prep_polygons (&p, np, donut_hell, step, bin_trouble);
 
 			if (clipping) {
 				for (k = level_to_be_painted; k < GMT_MAX_GSHHS_LEVEL - 1; k++) recursive_clipping (-1, np_new, p, k, k, &n_pieces);
@@ -788,10 +798,10 @@ int main (int argc, char **argv)
 						}
 				}
 			}
-			else if (!recursive) {	/* Simply points all polygons as is */
+			else if (!recursive) {	/* Simply paints all polygons as is */
 				for (k = 0; k < np_new; k++) {
 					if (p[k].n == 0 || p[k].level < lowest_level) continue;
-					level = p[k].level;
+					level = (int)p[k].level;
 					if (donut_hell && GMT_non_zero_winding (anti_x, anti_y, p[k].lon, p[k].lat, p[k].n)) {	/* Antipode inside polygon, must do donut */
 						n = GMT_map_clip_path (&xtmp, &ytmp, &donut);
 						ps_line (xtmp, ytmp, n, 1, TRUE);
@@ -823,7 +833,7 @@ int main (int argc, char **argv)
 		}
 
 		if (Ctrl->W.active && c.ns) {	/* Draw or dump shorelines, no need to assemble polygons */
-			if ((np = GMT_assemble_shore (&c, direction, FALSE, shift, west_border, east_border, &p)) == 0) continue;
+			if ((np = (int)GMT_assemble_shore (&c, direction, FALSE, shift, west_border, east_border, &p)) == 0) continue;
 
 			for (i = 0; i < np; i++) {
 				if (dumping) {
@@ -838,7 +848,7 @@ int main (int argc, char **argv)
 				else if (Ctrl->W.use[p[i].level-1]) {
 					if (donut_hell) p[i].n = GMT_fix_up_path (&p[i].lon, &p[i].lat, p[i].n, step, 0);
 					GMT_n_plot = GMT_geo_to_xy_line (p[i].lon, p[i].lat, p[i].n);
-					k = p[i].level - 1;
+					k = (int)(p[i].level - 1);
 					if (k != last_pen_level) {
 						GMT_setpen (&Ctrl->W.pen[k]);
 						last_pen_level = k;
@@ -871,7 +881,7 @@ int main (int argc, char **argv)
 
 		for (ind = 0; ind < r.nb; ind++) {	/* Loop over necessary bins only */
 
-			bin = r.bins[ind];
+			bin = (int)r.bins[ind];
 			GMT_get_br_bin (ind, &r, Ctrl->I.use, n_rlevels);
 
 			if (r.ns == 0) continue;
@@ -881,7 +891,7 @@ int main (int argc, char **argv)
 				shift = ((left - edge) <= 180.0 && (right - edge) > 180.0);
 			}
 
-			if ((np = GMT_assemble_br (&r, shift, edge, &p)) == 0) {
+			if ((np = (int)GMT_assemble_br (&r, shift, edge, &p)) == 0) {
 				GMT_free_br (&r);
 				continue;
 			}
@@ -900,7 +910,7 @@ int main (int argc, char **argv)
 					GMT_n_plot = GMT_geo_to_xy_line (p[i].lon, p[i].lat, p[i].n);
 					if (!GMT_n_plot) continue;
 
-					k = p[i].level;
+					k = (int)p[i].level;
 					if (k != last_k) {
 						GMT_setpen (&Ctrl->I.pen[k]);
 						last_k = k;
@@ -933,7 +943,7 @@ int main (int argc, char **argv)
 
 		for (ind = 0; ind < b.nb; ind++) {	/* Loop over necessary bins only */
 
-			bin = b.bins[ind];
+			bin = (int)b.bins[ind];
 			GMT_get_br_bin (ind, &b, Ctrl->N.use, n_blevels);
 
 			if (b.ns == 0) continue;
@@ -943,7 +953,7 @@ int main (int argc, char **argv)
 				shift = ((left - edge) <= 180.0 && (right - edge) > 180.0);
 			}
 
-			if ((np = GMT_assemble_br (&b, shift, edge, &p)) == 0) {
+			if ((np = (int)GMT_assemble_br (&b, shift, edge, &p)) == 0) {
 				GMT_free_br (&b);
 				continue;
 			}
@@ -963,7 +973,7 @@ int main (int argc, char **argv)
 					GMT_n_plot = GMT_geo_to_xy_line (p[i].lon, p[i].lat, p[i].n);
 					if (!GMT_n_plot) continue;
 
-					k = p[i].level - 1;
+					k = (int)(p[i].level - 1);
 					if (k != last_k) {
 						GMT_setpen (&Ctrl->N.pen[k]);
 						last_k = k;
@@ -1000,7 +1010,7 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "Done\n");
 	
-	Free_Pscoast_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_pscoast_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -1014,7 +1024,7 @@ void recursive_painting (int k0, int np, struct GMT_GSHHS_POL p[], int level, in
 
 	int k, flag;
 	char text[GMT_TEXT_LEN];
-	BOOLEAN add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k);
+	GMT_LONG add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k);
 	if (level > GMT_MAX_GSHHS_LEVEL) return;
 	flag = (level == start_level) ? 1 : 0;
 	for (k = k0 + 1; k < np; k++) {
@@ -1042,7 +1052,7 @@ void recursive_clipping (int k0, int np, struct GMT_GSHHS_POL *p, int level, int
 {
 	int k, flag;
 	char text[GMT_TEXT_LEN];
-	BOOLEAN add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k);
+	GMT_LONG add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k);
 	if (level > GMT_MAX_GSHHS_LEVEL) return;
 	for (k = k0 + 1; k < np; k++) {
 		if (p[k].n == 0 || p[k].level < level) continue;
@@ -1058,7 +1068,7 @@ void recursive_clipping (int k0, int np, struct GMT_GSHHS_POL *p, int level, int
 	}
 }
 
-BOOLEAN add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k)
+GMT_LONG add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, int k)
 {
 	/* Determines if we should add the current polygon pol[k] to the growing path we are constructing */
 
@@ -1073,11 +1083,11 @@ BOOLEAN add_this_polygon_to_path (int k0, struct GMT_GSHHS_POL *p, int level, in
 	return (FALSE);	/* No, we do not want to use this polygon */
 }
 
-void *New_Pscoast_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_pscoast_Ctrl () {	/* Allocate and initialize a new control structure */
 	int k;
 	struct PSCOAST_CTRL *C;
 
-	C = (struct PSCOAST_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCOAST_CTRL), "New_Pscoast_Ctrl");
+	C = (struct PSCOAST_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCOAST_CTRL), "New_pscoast_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 
@@ -1094,13 +1104,10 @@ void *New_Pscoast_Ctrl () {	/* Allocate and initialize a new control structure *
 	for (k = 0; k < GMT_MAX_GSHHS_LEVEL; k++) GMT_init_pen (&C->W.pen[k], GMT_PENWIDTH);	/* Default coastline pens */
 	memset ((void *)&C->L.item, 0, sizeof (struct GMT_MAP_SCALE));
 	memset ((void *)&C->T.item, 0, sizeof (struct GMT_MAP_ROSE));
-#ifdef DEBUG
-	C->debug.bin = -1;
-#endif
 
 	return ((void *)C);
 }
 
-void Free_Pscoast_Ctrl (struct PSCOAST_CTRL *C) {	/* Deallocate control structure */
+void Free_pscoast_Ctrl (struct PSCOAST_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);
 }
