@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: pstext.c,v 1.96 2009/07/11 03:16:31 guru Exp $
+ *	$Id: pstext.c,v 1.104 2010/06/30 10:05:14 remko Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -36,48 +36,48 @@
 
 struct PSTEXT_CTRL {
 	struct A {	/* -A */
-		BOOLEAN active;
+		GMT_LONG active;
 	} A;
 	struct C {	/* -C<dx>/<dy> */
-		BOOLEAN active;
-		BOOLEAN percent;
+		GMT_LONG active;
+		GMT_LONG percent;
 		double dx, dy;
 	} C;
 	struct D {	/* -D[j]<dx>/<dy>[v[<pen>] */
-		BOOLEAN active;
-		BOOLEAN justify;
-		BOOLEAN line;
+		GMT_LONG active;
+		GMT_LONG justify;
+		GMT_LONG line;
 		double dx, dy;
 		struct GMT_PEN pen;
 	} D;
 	struct E {	/* -Eazim/elev */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct G {	/* -G<fill> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_FILL fill;
 	} G;
 	struct L {	/* -L */
-		BOOLEAN active;
+		GMT_LONG active;
 	} L;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct S {	/* -S<pen> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_PEN pen;
 	} S;
 	struct W {	/* -W[<fill>][o|O|c[<pen>] */
-		BOOLEAN active;
-		BOOLEAN outline;
-		BOOLEAN paint;
+		GMT_LONG active;
+		GMT_LONG outline;
+		GMT_LONG paint;
 		GMT_LONG mode;
 		struct GMT_PEN pen;
 		struct GMT_FILL fill;
 	} W;
 	struct Z {	/* -Z<z_level> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;	/* 0 for common z_level, 1 for optional z-value in 3rd col for each record */
 		double level;
 	} Z;
@@ -111,9 +111,9 @@ int main(int argc, char **argv)
 	double xy[2], west = 0.0, east = 0.0, south = 0.0, north = 0.0, plot_x = 0.0, plot_y = 0.0;
 	double z_level = 0.0, tmp, dx, dy, xx[2], yy[2], z_level_orig = 0.0;
 
-	BOOLEAN error = FALSE, nofile = TRUE, master_record = FALSE;
-	BOOLEAN do_paragraphs = FALSE, done = FALSE, old_GMT_world_map, add;
-	BOOLEAN skip_text_records = FALSE;
+	GMT_LONG error = FALSE, nofile = TRUE, master_record = FALSE;
+	GMT_LONG do_paragraphs = FALSE, done = FALSE, old_GMT_world_map, add;
+	GMT_LONG skip_text_records = FALSE;
 
 	char text[BUFSIZ], line[BUFSIZ], this_font[GMT_LONG_TEXT], just_key[5], txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT];
 	char txt_x[GMT_LONG_TEXT], txt_y[GMT_LONG_TEXT], txt_z[GMT_LONG_TEXT], p[BUFSIZ];
@@ -125,12 +125,12 @@ int main(int argc, char **argv)
 	struct PSTEXT_CTRL *Ctrl;
 
 	void GMT_putwords (double x, double y, char **text, GMT_LONG n_words, struct PSTEXT_INFO *info);
-	void *New_Pstext_Ctrl (), Free_Pstext_Ctrl (struct PSTEXT_CTRL *C);
+	void *New_pstext_Ctrl (), Free_pstext_Ctrl (struct PSTEXT_CTRL *C);
 	void load_parameters (struct PSTEXT_INFO *T, struct PSTEXT_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct PSTEXT_CTRL *)New_Pstext_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSTEXT_CTRL *)New_pstext_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	memset ((void *)&T, 0, sizeof (struct PSTEXT_INFO));
 
@@ -157,6 +157,7 @@ int main(int argc, char **argv)
 				case 'Y':
 				case 'y':
 				case 'c':
+				case 'f':
 				case 'm':
 				case ':':
 				case '\0':
@@ -301,8 +302,8 @@ int main(int argc, char **argv)
 		fprintf (stderr, "usage: pstext <txtfile> %s %s\n", GMT_J_OPT, GMT_Rgeoz_OPT);
 		fprintf (stderr, "\t[-A] [%s] [-C<dx>/<dy>] [-D[j]<dx>[/<dy>][v[<pen>]] [%s] [-G<color>]\n", GMT_B_OPT, GMT_E_OPT);
 		fprintf (stderr, "\t[%s] [-K] [-L] [-N] [-O] [-P] [-S<pen>] [%s]\n", GMT_Ho_OPT, GMT_U_OPT);
-		fprintf (stderr, "\t[-V] [-W[<fill>,][o|O|c|C[<pen>]]] [%s] [%s]\n", GMT_X_OPT, GMT_X_OPT);
-		fprintf (stderr, "\t[-Z[<zlevel>|+]] [%s] [%s] [%s]\n\n", GMT_t_OPT, GMT_c_OPT, GMT_mo_OPT);
+		fprintf (stderr, "\t[-V] [-W[<fill>,][o|O|c|C[<pen>]]] [%s] [%s]\n", GMT_X_OPT, GMT_Y_OPT);
+		fprintf (stderr, "\t[-Z[<zlevel>|+]] [%s] [%s] [%s] [%s]\n\n", GMT_t_OPT, GMT_c_OPT, GMT_f_OPT, GMT_mo_OPT);
 		fprintf (stderr, "\tReads (x,y,size,angle,fontno,justify,text) from <txtfile> [or stdin]\n");
 		fprintf (stderr, "\tOR (with -m) one or more text paragraphs with formatting info in the segment header.\n");
 		fprintf (stderr, "\tjustify is of the form [T|M|B][L|C|R] (top/middle/bottom/left/center/right)\n");
@@ -361,6 +362,7 @@ int main(int argc, char **argv)
 		fprintf (stderr, "\t   records to have an optional z value in the 3rd column (i.e., x y z size ...)\n");
 		fprintf (stderr, "\t   Note that -Z+ also sets -N\n");
 		GMT_explain_option ('c');
+		GMT_explain_option ('f');
 		GMT_explain_option ('m');
 		fprintf (stderr, "\t   Expects (x y size angle fontno justify linespace parwidth parjust) in segment header\n");
 		fprintf (stderr, "\t   followed by lines with one or more paragraphs of text.\n");
@@ -508,7 +510,7 @@ int main(int argc, char **argv)
 					if (!Ctrl->N.active) {
 						skip_text_records = TRUE;	/* If this record should be skipped we must skip the whole paragraph */
 						GMT_map_outside (xy[0], xy[1]);
-						if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
+						if (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1) continue;
 						skip_text_records = FALSE;	/* Since we got here we do not want to skip */
 					}
 					if (Ctrl->A.active) {
@@ -592,7 +594,7 @@ int main(int argc, char **argv)
 				xx[0] = plot_x;	yy[0] = plot_y;
 				if (!Ctrl->N.active) {
 					GMT_map_outside (xy[0], xy[1]);
-					if ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1) continue;
+					if (GMT_abs (GMT_x_status_new) > 1 || GMT_abs (GMT_y_status_new) > 1) continue;
 				}
 
 				T.block_justify = (isdigit ((int)just_key[0])) ? atoi (just_key) : GMT_just_decode (just_key, 12);
@@ -688,7 +690,7 @@ int main(int argc, char **argv)
 
 	GMT_free ((void *)use_font);
 
-	Free_Pstext_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_pstext_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -756,10 +758,10 @@ void load_parameters (struct PSTEXT_INFO *T, struct PSTEXT_CTRL *C) {
 
 }
 
-void *New_Pstext_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_pstext_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSTEXT_CTRL *C;
 	
-	C = (struct PSTEXT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSTEXT_CTRL), "New_Pstext_Ctrl");
+	C = (struct PSTEXT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSTEXT_CTRL), "New_pstext_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 		
@@ -777,6 +779,6 @@ void *New_Pstext_Ctrl () {	/* Allocate and initialize a new control structure */
 	return ((void *)C);
 }
 
-void Free_Pstext_Ctrl (struct PSTEXT_CTRL *C) {	/* Deallocate control structure */
+void Free_pstext_Ctrl (struct PSTEXT_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
