@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: spectrum1d.c,v 1.44 2009/09/09 23:27:04 guru Exp $
+ *	$Id: spectrum1d.c,v 1.50 2010/06/10 23:52:05 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -74,28 +74,28 @@
 
 struct SPECTRUM1D_CTRL {
 	struct C {	/* -C[<xycnpago>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		char col[SPECTRUM1D_N_OUTPUT_CHOICES];	/* Character codes for desired output in the right order */
 	} C;
 	struct D {	/* -D<inc> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double inc;
 	} D;
 	struct N {	/* -N<namestem> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *name;
 	} N;
 	struct S {	/* -S<segment_size> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG size;
 	} S;
 	struct W {	/* -W */
-		BOOLEAN active;
+		GMT_LONG active;
 	} W;
 };
 
 struct SPECTRUM1D_INFO {	/* Control structure for spectrum1d */
-	BOOLEAN	y_given;
+	GMT_LONG	y_given;
 	GMT_LONG	n_spec, window, window_2;
 	float	*datac;
 	double	dt, x_variance, y_variance, d_n_windows, y_pow;
@@ -111,11 +111,11 @@ struct SPECTRUM1D_INFO {	/* Control structure for spectrum1d */
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE;
+	GMT_LONG	error = FALSE;
 	
 	char	buffer[BUFSIZ], *not_used = NULL;
 
-	GMT_LONG	i, k, j, n_expected_fields, n_fields, n_outputs, window_test = 2;
+	GMT_LONG	i, k, j, n_expected_fields, n_fields, n_read, n_outputs, window_test = 2;
 	GMT_LONG	n_alloc, n_data;
 
 	float	*x, *y = NULL;
@@ -129,13 +129,13 @@ int main (int argc, char **argv)
 
 	void alloc_arrays (struct SPECTRUM1D_INFO *C);
 	void compute_spectra (struct SPECTRUM1D_INFO *C, float *x, float *y, GMT_LONG n_data);
-	void write_output (struct SPECTRUM1D_INFO *C, char *cols, GMT_LONG n_outputs, BOOLEAN write_wavelength, char *namestem);
+	void write_output (struct SPECTRUM1D_INFO *C, char *cols, GMT_LONG n_outputs, GMT_LONG write_wavelength, char *namestem);
 	void free_space (struct SPECTRUM1D_INFO *C);
-	void *New_Spectrum1d_Ctrl (), Free_Spectrum1d_Ctrl (struct SPECTRUM1D_CTRL *C);
+	void *New_spectrum1d_Ctrl (), Free_spectrum1d_Ctrl (struct SPECTRUM1D_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct SPECTRUM1D_CTRL *)New_Spectrum1d_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct SPECTRUM1D_CTRL *)New_spectrum1d_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	memset ((void *)&C, 0, sizeof (struct SPECTRUM1D_INFO));
 	
@@ -152,7 +152,7 @@ int main (int argc, char **argv)
 				case 'b':
 				case 'f':
 				case '\0':
-					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
+					error += (GMT_LONG)GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
 
 				/* Supplemental parameters */
@@ -206,7 +206,7 @@ int main (int argc, char **argv)
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {	/* Display usage */
-		fprintf (stderr, "spectrum1d %s - compute auto- [and cross- ] spectra from one [or two] timeseries\n\n", GMT_VERSION);
+		fprintf (stderr, "spectrum1d %s - Compute auto- [and cross- ] spectra from one [or two] timeseries\n\n", GMT_VERSION);
 		fprintf(stderr,"usage:  spectrum1d -S<segment_size> [-C[<xycnpago>]] [-D<dt>] [%s] [-N<name_stem>]\n", GMT_H_OPT);
 		fprintf(stderr,"\t[-V] [-W] [%s] [%s]\n\n", GMT_b_OPT, GMT_f_OPT);
 
@@ -255,7 +255,7 @@ int main (int argc, char **argv)
 	}
         if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN] = (Ctrl->C.active + 1);
         if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < (Ctrl->C.active + 1)) {
-                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data must have at least %d columns\n", GMT_program, Ctrl->C.active + 1);
+                fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data must have at least %ld columns\n", GMT_program, Ctrl->C.active + 1);
 		error++;
 	}
 
@@ -296,7 +296,7 @@ int main (int argc, char **argv)
 #endif
 	}
 	n_alloc = GMT_CHUNK;
-	n_data = 0;
+	n_data = n_read = 0;
 	x = (float *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(float), GMT_program);
 	if (C.y_given) y = (float *)GMT_memory (VNULL, (size_t)n_alloc, sizeof(float), GMT_program);
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : C.y_given + 1;
@@ -305,9 +305,11 @@ int main (int argc, char **argv)
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
+		n_read++;
+
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_data);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
+			continue;
 		}
 
                 x[n_data] = (float)in[GMT_X];
@@ -334,7 +336,7 @@ int main (int argc, char **argv)
 
 	free_space (&C);
 
-	Free_Spectrum1d_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_spectrum1d_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -466,7 +468,7 @@ void compute_spectra (struct SPECTRUM1D_INFO *C, float *x, float *y, GMT_LONG n_
 	}
 }
 
-void write_output (struct SPECTRUM1D_INFO *C, char *col, GMT_LONG n_outputs, BOOLEAN write_wavelength, char *namestem)
+void write_output (struct SPECTRUM1D_INFO *C, char *col, GMT_LONG n_outputs, GMT_LONG write_wavelength, char *namestem)
 {
 	GMT_LONG	i, j;
 	double	delta_f, eps_pow, out[3], *f_or_w;
@@ -687,10 +689,10 @@ void detrend_and_hanning (struct SPECTRUM1D_INFO *C)
 		C->x_variance /= C->window;
 	}
 }
-void *New_Spectrum1d_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_spectrum1d_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct SPECTRUM1D_CTRL *C;
 	
-	C = (struct SPECTRUM1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SPECTRUM1D_CTRL), "New_Spectrum1d_Ctrl");
+	C = (struct SPECTRUM1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SPECTRUM1D_CTRL), "New_spectrum1d_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->D.inc = 1.0;
@@ -706,7 +708,7 @@ void *New_Spectrum1d_Ctrl () {	/* Allocate and initialize a new control structur
 	return ((void *)C);
 }
 
-void Free_Spectrum1d_Ctrl (struct SPECTRUM1D_CTRL *C) {	/* Deallocate control structure */
+void Free_spectrum1d_Ctrl (struct SPECTRUM1D_CTRL *C) {	/* Deallocate control structure */
 	if (C->N.name) free ((void *)C->N.name);	
 	GMT_free ((void *)C);	
 }
